Create a list with DE parameters for Minimization.
getDEInfo(
nPop = 32,
maxIter = 100,
deType = "rand-1",
freeRun = 1,
tol = 1e-06,
sf = 0.5,
cr = 0.1
)A list of DE parameter settings.
A integer number of population size in DE algorithm.
A integer number of maximal DE iterations.
string. The type of DE. This package current supports the following types:
Mutation operation on the current position with one random direction
Mutation operation on the current position with two random directions
Mutation operation on the best position with one random direction
Mutation operation on the best position with two random directions
Mutation operation on the current position with direction to the best and one random direction
Mutation operation on the current position with direction to the best and two random directions
The default type is `rand-1`.
A number between \([0,1]\) that controls the percentage of DE iterations which are free from examining the stopping criterion, \(|f'-f|<\varepsilon\) where \(f'\) and \(f\) are the objective function values in the previous and current iterations, respectively. The default is 1.0 implying the DE will completely ignore the stopping criterion. Otherwise, the DE checks the stopping criterion after free iterations.
A small value for the tolerance, \(\varepsilon\), in the stopping criterion.
For freeRun smaller than 1.0, the default is 1e-6. Otherwise, this value would not affect the algorithm.
The value of scaling factor in DE updating procedure. The default is 0.5.
The value of crossover rate in DE updating procedure. The default is 0.1.
DE_INFO <- getDEInfo(nPop = 32, maxIter = 100)
Run the code above in your browser using DataLab